@@ -20,7 +20,7 @@ if __name__ == '__main__':
 
     cmd_list = ['bash -c \'id %s | grep "%s"  2> /dev/null\'' % (pam_user, site_group)]
     if CONF_MAP['UADM_USE_CENTRIFY']:
-        cmd_list.append('bash -c \'adquery user %s -a 2> /dev/null | grep "%s"\'' % (pam_user, site_group))
+        cmd_list.append('bash -c \'adquery group %s -m 2> /dev/null | grep "%s"\'' % (site_group, pam_user))
 
     is_member = False
     for c in cmd_list:
